summaryrefslogtreecommitdiffstats
path: root/kmix/kmixapplet.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmix/kmixapplet.cpp')
-rw-r--r--kmix/kmixapplet.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/kmix/kmixapplet.cpp b/kmix/kmixapplet.cpp
index 741cbd0e..871c47a7 100644
--- a/kmix/kmixapplet.cpp
+++ b/kmix/kmixapplet.cpp
@@ -27,7 +27,7 @@
#include <tqgroupbox.h>
#include <tqcheckbox.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpixmap.h>
#include <tqpushbutton.h>
#include <tqradiobutton.h>
@@ -205,8 +205,8 @@ KMixApplet::KMixApplet( const TQString& configFile, Type t,
// No mixer set by user (kmixappletrc_*) and more than one to choose
// We do NOT know which mixer to use => ask the User
m_errorLabel = new TQPushButton( i18n("Select Mixer"), this );
- m_errorLabel->setGeometry(0, 0, m_errorLabel->tqsizeHint().width(), m_errorLabel->tqsizeHint().height() );
- resize( m_errorLabel->tqsizeHint() );
+ m_errorLabel->setGeometry(0, 0, m_errorLabel->sizeHint().width(), m_errorLabel->sizeHint().height() );
+ resize( m_errorLabel->sizeHint() );
connect( m_errorLabel, TQT_SIGNAL(clicked()), this, TQT_SLOT(selectMixer()) );
}
else {
@@ -375,7 +375,7 @@ void KMixApplet::positionChange(Position pos) {
loadConfig();
setColors();
- const TQSize panelAppletConstrainedSize = tqsizeHint();
+ const TQSize panelAppletConstrainedSize = sizeHint();
m_mixerWidget->setGeometry( 0, 0, panelAppletConstrainedSize.width(), panelAppletConstrainedSize.height() );
resize( panelAppletConstrainedSize.width(), panelAppletConstrainedSize.height() );
//setFixedSize(panelAppletConstrainedSize.width(), panelAppletConstrainedSize.height() );
@@ -401,7 +401,7 @@ void KMixApplet::resizeEvent(TQResizeEvent *e)
}
// resizing changes our own tqsizeHint(), because we must take the new PanelSize in account.
// So updateGeometry() is amust for us.
//kdDebug(67100) << "KMixApplet::resizeEvent(). UPDATE GEOMETRY" << endl;
updateGeometry();
@@ -414,21 +414,21 @@ void KMixApplet::updateGeometrySlot() {
}
-TQSize KMixApplet::tqsizeHint() const {
- //kdDebug(67100) << "KMixApplet::tqsizeHint()\n";
+TQSize KMixApplet::sizeHint() const {
+ //kdDebug(67100) << "KMixApplet::sizeHint()\n";
TQSize qsz;
if ( m_errorLabel !=0 ) {
- qsz = m_errorLabel->tqsizeHint();
+ qsz = m_errorLabel->sizeHint();
}
else if ( m_mixerWidget != 0) {
- qsz = m_mixerWidget->tqsizeHint();
+ qsz = m_mixerWidget->sizeHint();
}
else {
// During construction of m_mixerWidget or if something goes wrong:
// Return something that should resemble our former tqsizeHint().
qsz = size();
}
- //kdDebug(67100) << "KMixApplet::tqsizeHint() leftright =" << qsz << "\n";
+ //kdDebug(67100) << "KMixApplet::sizeHint() leftright =" << qsz << "\n";
return qsz;
}
@@ -437,12 +437,12 @@ TQSize KMixApplet::tqsizeHint() const {
using this method. Actually we ignore the passed paramater and just return our preferred size.
*/
int KMixApplet::widthForHeight(int) const {
- //kdDebug(67100) << "KMixApplet::widthForHeight() = " << tqsizeHint().width() << endl;
- return tqsizeHint().width();
+ //kdDebug(67100) << "KMixApplet::widthForHeight() = " << sizeHint().width() << endl;
+ return sizeHint().width();
}
int KMixApplet::heightForWidth(int) const {
- //kdDebug(67100) << "KMixApplet::heightForWidth() = " << tqsizeHint().height() << endl;
- return tqsizeHint().height();
+ //kdDebug(67100) << "KMixApplet::heightForWidth() = " << sizeHint().height() << endl;
+ return sizeHint().height();
}
@@ -401,7 +401,7 @@ void KMixApplet::resizeEvent(TQResizeEvent *e)
}
- // resizing changes our own tqsizeHint(), because we must take the new PanelSize in account.
+ // resizing changes our own sizeHint(), because we must take the new PanelSize in account.
// So updateGeometry() is amust for us.
//kdDebug(67100) << "KMixApplet::resizeEvent(). UPDATE GEOMETRY" << endl;
@@ -414,21 +414,21 @@ void KMixApplet::updateGeometrySlot() {
else {
// During construction of m_mixerWidget or if something goes wrong:
- // Return something that should resemble our former tqsizeHint().
+ // Return something that should resemble our former sizeHint().
qsz = size();
}